"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.requestMiddleware = exports.getOrGenerateMockData = void 0;
const path_1 = require("path");
const ts_mock_generator_1 = require("ts-mock-generator");
const utils_1 = require("../utils");
let mockData;
const getOrGenerateMockData = async (opts) => {
    const mockDataResolver = new ts_mock_generator_1.MockDataResolver({
        configPath: path_1.join(process.cwd(), 'tsconfig.json'),
        basePath: path_1.join(process.cwd(), opts.basePath),
        mockDir: path_1.join(process.cwd(), opts.basePath, 'mock'),
        includes: opts.includes || [],
    });
    mockData = mockDataResolver.getOrGenerateData();
    if (opts.watchFile) {
        mockDataResolver.watchMockFile((data) => {
            mockData = data;
        });
        mockDataResolver.watchRequestFile((data) => {
            mockData = data;
        });
    }
};
exports.getOrGenerateMockData = getOrGenerateMockData;
const getTargetMockData = (url) => mockData.filter((data) => data.url === url);
const isGet = (method) => method && method.toUpperCase() === 'GET';
const sleep = (delay) => new Promise((resolve) => {
    setTimeout(() => {
        resolve(null);
    }, delay);
});
const requestMiddleware = async (req, res, next) => {
    let url = isGet(req.method) ? req.url?.split('?')[0] : req.url;
    const targetMockData = getTargetMockData(url);
    if (targetMockData.length > 0) {
        utils_1.logger.info(`invoke mock proxy: ${url}`);
        const data = targetMockData[0];
        if (data.timeout) {
            await sleep(data.timeout);
        }
        res.setHeader('Content-Type', 'application/json');
        res.statusCode = data.httpCode ? data.httpCode : 200;
        res.end(JSON.stringify(data.response));
        return;
    }
    next();
};
exports.requestMiddleware = requestMiddleware;
